@@ -46,11 +46,23 @@ where
 		self.map.len()
 	}
 
+	pub fn is_empty(&self) -> bool
+	where
+		T: Measure,
+	{
+		self.len() == T::Len::default()
+	}
+
 	pub fn iter(&self) -> Iter<T, C> {
 		Iter {
 			inner: self.map.iter(),
 		}
 	}
+
+	/// Returns an iterator over the gaps (missing values) of the set.
+	pub fn gaps(&self) -> Gaps<T, C> {
+		self.map.gaps()
+	}
 }
 
 impl<'a, T, C: Slab<Node<AnyRange<T>, ()>>> IntoIterator for &'a RangeSet<T, C>
@@ -83,6 +95,14 @@ where
 	{
 		self.map.remove(key)
 	}
+
+	pub fn complement(&self) -> Self
+	where
+		T: Clone + Measure + PartialOrd,
+		C: Default,
+	{
+		self.gaps().map(AnyRange::cloned).collect()
+	}
 }
 
 impl<K, L, C: Slab<Node<AnyRange<K>, ()>>, D: Slab<Node<AnyRange<L>, ()>>> PartialEq<RangeSet<L, D>>
@@ -184,3 +204,34 @@ where
 		self.inner.next().map(|(range, _)| range)
 	}
 }
+
+/// Iterator over the gaps (unbound keys) of a `RangeSet`.
+pub type Gaps<'a, T, C> = crate::generic::map::Gaps<'a, T, (), C>;
+
+impl<R: AsRange, C: SlabMut<Node<AnyRange<R::Item>, ()>>> std::iter::Extend<R>
+	for RangeSet<R::Item, C>
+where
+	R::Item: Clone + Measure + PartialOrd,
+	for<'r> C::ItemRef<'r>: Into<&'r Node<AnyRange<R::Item>, ()>>,
+	for<'r> C::ItemMut<'r>: Into<&'r mut Node<AnyRange<R::Item>, ()>>,
+{
+	fn extend<I: IntoIterator<Item = R>>(&mut self, iter: I) {
+		for range in iter {
+			self.insert(range)
+		}
+	}
+}
+
+impl<R: AsRange, C: Default + SlabMut<Node<AnyRange<R::Item>, ()>>> FromIterator<R>
+	for RangeSet<R::Item, C>
+where
+	R::Item: Clone + Measure + PartialOrd,
+	for<'r> C::ItemRef<'r>: Into<&'r Node<AnyRange<R::Item>, ()>>,
+	for<'r> C::ItemMut<'r>: Into<&'r mut Node<AnyRange<R::Item>, ()>>,
+{
+	fn from_iter<I: IntoIterator<Item = R>>(iter: I) -> Self {
+		let mut result = Self::default();
+		result.extend(iter);
+		result
+	}
+}
